.. rst-class:: detail

SetTool
==================

.. currentmodule:: compas_rrc

.. autoclass:: SetTool

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetTool.__init__
        ~SetTool.from_msg
    
    